# La charge électrique et le champs électrique

Les forces électriques sont omniprésentes dans notre vie de tous les jours.
Elles permettent d'allumer des ampoules, de faire fonctionner les 
ordinateurs, de faire tourner des moteurs, ... Elles sont aussi
responsables des interactions inter-atomiques pour que des amas d'atomes 
formes des solides ou les liquides. En réalité un certain nombre des
forces que nous avons considéré dans le chapitre précédent sont
le résultat des interactions électrique au niveau atomique (la force de
frottement par exemple).

## L'électricité statique et la conservation de la charge électrique

Lorsqu'on frotte un ballon de baudruche contre sa tête, on constate
que les cheveux ont tendances à rester attachés au ballon
plutôt que de tomber vers le sol sous l'effet de la gravité.
On dit aujourd'hui que les cheveux se dresse sous l'effet de l'**électricité statique**.
En réalité sous l'effet du frottement le ballon comme les cheveux deviennent "chargés":
il possèdent une **charge électrique**.

Il existe *deux* types de charges électriques: la charge *positive* et la charge *négative*.
Des objets possédant une charge de *même* type ont tendance à se repousser,
alors que ceux possédant des charges *opposées*
ont tendance à se repousser mutuellement.

L'expérience de charger un objet en le frottant peut amener à charger positivement ou 
négativement un objet. Ainsi, on dit qu'une baguette en verre est chargée *positivement*,
alors qu'une baguette en plastique est chargée *négativement*. Ce choit est totalement arbitraire
et a été choisi par B. Franklin (au 18e siècle) qui a été un des premiers à faire ce type d'expériences.

Avant de frotter ses cheveux contre un ballon et de rendre les cheveux et le ballon chargé,
on constate qu'il n'y a pas d'attraction particulière entre ces deux objets. Cela signifie
que ni l'un ni l'autre ne sont chargés. En fait le frottement va donner une charge 
*égale et opposée* à chaque objet.

Cela est une conséquence de la loi de la conservation de la charge électrique qui dit que

* La charge totale produite par un processus est nulle,

ou en d'autre termes

* Aucune charge ne peut être créée ou détruite.

En pratique cela signifie que si une région de l'espace acquière une charge positive
une autre région aura acquis dans le même temps la même charge mais négative.

---

#### Question {-}

Connaissez-vous d'autres lois de conservation?

---

## La charge électrique dans les atomes

Un modèle simplifié d'un atome postule qu'un atome possède un noyau chargé positivement (composé de 
protons et de neutrons, ces derniers n'ont pas de charge) autour duquel tournent les électrons chargés négativement (voir @fig:bohr). Les protons ont exactement la même charge électrique que les électron
mais inversée. Ainsi les atomes n'ont pas une charge nette.

![Illustration du modèle de l'atome de Bohr. Source: [Wikipedia](https://upload.wikimedia.org/wikipedia/commons/2/2c/Blausen_0342_ElectronEnergyLevels.png)](https://upload.wikimedia.org/wikipedia/commons/2/2c/Blausen_0342_ElectronEnergyLevels.png){#fig:bohr width=40%}

Sous l'effet du frottement (entre autres) un atome peut perdre ou gagner des électrons.
Il devient ainsi positivement ou négativement chargé (respectivement),
et est appelé un *ion*. Les atomes dans un solide ont une structure
cristalline (ils ne peuvent quasiment pas bouger). De plus dans des isolants
les électrons sont également fortement attachés à leurs noyaux, alors que dans
des conducteurs ils sont libres de se mouvoir à la surface du solide. Ainsi,
lorsqu'on frotte un isolant (un ballon) avec un autre isolant (les cheveux),
des électrons sont transférés de l'un vers l'autre ce qui conduit
à un transfère net de charge. Cette charge nette ne dure pas indéfiniment
car les électrons en trop sont diffusés dans l'air, attirés par les molécules d'eau
en général.

## Isolants et conducteurs

Si nous sommes en présence de deux objets métalliques. Un chargé électriquement
et un autre neutre et qu'on connecte les deux objets à l'aide
d'un fil métallique, on constate que l'objet non chargé devient rapidement chargé.
A l'inverse si on connecte les deux objets métalliques avec
un morceau de plastique, la charge de l'objet neutre ne changera pas.

Les objets métalliques sont de bons *conducteurs* d'électricité, alors que
le plastique est un *isolant* (il conduit mal l'électricité). Il existe également
une sorte intermédiaire qui est à mi-chemin entre isolant et conducteur: 
les *semi-conducteurs*. Le silicium entre dans cette catégorie par exemple (le silicium est un composant très important des ordinateurs).
Nous parlerons des semi-conducteurs plus tard dans ce cours.

La différence entre isolant et conducteur au niveau atomique est la suivante.
Les électrons dans un isolant sont très fortement attachés au noyaux. Pour un conducteur
en revanche, certains électrons ont un lien beaucoup plus faible avec le noyau
et peuvent se déplacer librement à la surface du matériau conducteur (mais pas s'en détacher).
Ces électrons sont appelés *électrons libres*. Ainsi, un matériau chargé qui entre en contact
avec un conducteur, va avoir pour effet de déplacer les électrons de celui-ci.
Si la charge est positive, les électrons se déplaceront vers le la charge,
à l'inverse il s'en éloigneront si la charge est négative.

Pour en revenir à notre exemple du début de la section, lorsqu'un
conducteur neutre, $N$, est mis en contact avec un autre conducteur chargé positivement, $C$,
le conducteur $N$ deviendra également positivement chargé. 
En effet, lorsque $N$ et $C$ sont mis en contact les électrons de $N$
sont attirés par la charge positive de $C$, et certains passeront de $N$ à
$C$, diminuant la charge nette de $C$ et augmentant la charge positive
de $N$, jusqu'à ce que $N$ et $C$ aient la même charge. Ce processus
est appelé charge par *conduction* car les deux conducteurs sont en contact
direct.

Si maintenant les deux objets sont rapprochés, mais sans être mis en contact. Les électrons libres ne vont pas quitter le conducteur $N$ pour rejoindre le conducteur $C$. En revanche, les électrons de $N$
seront attirés par le conducteur $C$ et se déplaceront en direction
de $C$ créant ainsi deux zones à l'intérieure de $N$: une chargée négativement proche de $C$, et une positivement éloignée de $C$.
Néanmoins, la charge nette de $N$ reste toujours la même,
c'est à dire nulle. Ce processus est appelé charge par *induction*.

---

Question (Charger un conducteur) #

Pouvez-vous imaginer un processus pour charger un conducteur en utilisant
la charge par induction?

---

Ce processus permet de charger un objet assez facilement.
Pour ce faire, il faut connecter l'objet à l'aide d'un conducteur à la Terre[^8] (à l'aide d'un fil par exemple). Puis en utilisant la
charge par induction les électrons vont quitter (ou pénétrer)
le conducteur depuis la Terre. Puis il suffit de couper le
fil et le tour est joué.

## La loi de Coulomb

Dans les précédentes sections, nous avons vu la phénoménologie
de la force que les charges électriques peuvent exercer entre
elles. Ces forces peuvent être attractives ou répulsives, mais
nous ne savons pas encore quelle peut être la magnitude de cette
force. 

---

Question (Force électrique) #

De quoi dépend la force électrique à votre avis?

---

La force électrique a été étudiée par Charles Coulomb au 18e siècle 
(1780 environ) à l'aide d'une *balance à torsion*. Cette balance
est basée sur le même principe qu'une balance pour la gravitation mais
adaptée à la force électrique (une vidéo décrivant l'expérience
peut se trouver [sur ce lien](https://bit.ly/3nOgZEN)).

Un axe avec une boule conductrice à une extrémité est suspendue
à un long fil très fin. Le dispositif est enfermé dans une cloche
en verre limitant ainsi les courants d'air. Dans cette cloche
on peut introduire un autre conducteur chargé. Lorsque les boules sont mises en contact, la charge est répartie entre les deux objet et ils se repoussent. Cette force induit une torsion du fil,
et on peut ainsi mesurer l'amplitude de la force. Ainsi on peut mesurer
la torsion du fil sous l'effet de la force électrique.
En variant la distance de départ entre les charges, et en utilisant
plus d'objets, Coulomb a pu déterminer sa loi reliant la force électrique avec la distance et la charge.

Coulomb énonce que la force électrique
entre deux object de charges $Q_1$, et $Q_2$, est proportionnelle au produit des charges en présence et inversément
proportionnelle au carré de la distance, $r$, qui les sépare[^9].
Cela peut s'écrire sous la forme
$$
F=k\frac{Q_1\cdot Q_2}{r^2},
$$
où $k$ est la constante de proportionnalité.

La force est toujours dans la direction de la ligne reliant
les deux charges. Si les deux charges ont le même signe la force est
répulsive (la force éloigne les charges), si les deux charges ont un signe opposé, la force est attractive (la force attire les charges l'une vers l'autre).

---

Question (Action-réaction) #

Est-ce que la loi de Coulomb est compatible avec la troisième loi de Newton (principe d'action-réaction)?

---

On constate que la loi de Coulomb est effectivement compatible
avec la troisième loi de Newton (encore heureux!). En effet,
l'amplitude de la force est la même quelque soit la charge ($Q_1$ ou $Q_2$) de l'objet que nous considérons, et les forces sont également opposées en direction étant donnée qu'elles sont
répulsives ou attractives.

---

Remarque (Force de gravitation) #

On constate que la loi de Coulomb est très similaire à la
loi de gravitation universelle pour deux masses $m_1$, $m_2$,
séparée par une distance $r$
$$
F=G\frac{m_1\cdot m_2}{r^2},
$$
où $G$ est la constante de gravitation universelle.

---

L'unité de la charge électrique est le *Coulomb*, $[\mathrm{C}]$.

---

Questions (Unités de $k$) #

Quelles sont les unités de la constante $k$?

---

En SI la constante $k$ a pour valeur
$$
k=8.988\cdot 10^9\ \frac{\mathrm{N}\cdot \mathrm{m}^2}{\mathrm{C}^2},
$$
où $\mathrm{C}$ est le *Coulomb*, l'unité de la charge électrique.

Pour avoir une idée de ce que représentent ces grandeurs,
voyons quelle force exerceraient entre elles deux charges
d'un Coulomb séparées d'un mètre:
$$
F\cong 9\cdot 10^9\frac{\cdot 1\cdot 1}{1^2}=9\cdot 10^9\ \mathrm{N}.
$$
Cela correspond au poids d'un objet de presque $10^9\ \kg$!
On voit qu'un Coulomb est une charge gigantesque qu'on ne rencontre pas fréquemment dans la nature. Typiquement, les charges sont plutôt de l'ordre du $\mu C$ (soit $10^{-6}$ Coulombs).




